@@ -13,7 +13,7 @@ try:
 except ImportError:
     import moves
 
-VERSION = '0.0.9'
+VERSION = '0.0.10'
 
 class Ansi:
     """ The terminal ansi chars """
@@ -403,16 +403,16 @@ class Game:
 
 def show_help():
     """ Prints the help message """
-    print('''TChess - Play the chess in terminal
+    print('''tchess - Play the chess in terminal
+
+SYNOPSIS
+    $ '''+sys.argv[0]+''' [options...] [?game-file-name]
 
 DESCRIPTION
     The TChess is a chess game in terminal.
     This software can handle saving the game in a file
     Then you can continue your game later by loading that file
 
-SYNOPSIS
-    $ '''+sys.argv[0]+''' [options...] [?game-file-name]
-
 OPTIONS
     --help: shows this help
     --version|-v: shows the version of tchess
@@ -431,8 +431,16 @@ AUTHOR
 def load_game_from_file(path: str):
     """ Loads the game object from a file """
     tmp_f = open(path, 'rb')
-    game = pickle.load(tmp_f)
+    file_game = pickle.load(tmp_f)
     tmp_f.close()
+    game = Game()
+    game.turn = str(file_game.turn)
+    game.logs = list(file_game.logs)
+    game.version = int(file_game.version)
+    game.highlight_cells = list(file_game.highlight_cells)
+    game.white_player = str(file_game.white_player)
+    game.black_player = str(file_game.black_player)
+    game.board = list(file_game.board)
     return game
 
 def run(args=[]):
